@@ -1,9 +1,6 @@
 .First.lib = function(lib, pkg) {
 
-cat("attaching languageR\n")
-
-require(methods, quietly = TRUE)
-#require(lme4, quietly=TRUE)
+packageStartupMessage("attaching languageR\n")
 
 #setMethod("show", "corres", function(object) print.corres(object))
 #setMethod("show", "growth", function(object) show.growth(object))
